@@ -1,11 +1,13 @@
 ﻿from __future__ import annotations
 
+import functools
 import threading
-from typing import Dict, Tuple, Callable, List, Optional
+from typing import Dict, Tuple, Callable, List, Optional, Any
 
 from SingleLog import LogLevel, DefaultLogger
 
-from . import _api_bucket, __version__
+from . import __version__
+from . import _api_bucket
 from . import _api_change_pw
 from . import _api_comment
 from . import _api_del_post
@@ -121,12 +123,11 @@ class API:
 
         self.connect_core = connect_core.API(self.config)
         self._exist_board_list = []
-        self._board_info_list = dict()
         self._moderators = dict()
-        # self._last_throw_water_ball_time = 0
         self._thread_id = threading.get_ident()
         self._goto_board_list = []
         self._board_info_list = dict()
+        self._newest_index_data = data_type.TimedDict(timeout=2)
 
         self.logger.debug('ThreadID', self._thread_id)
 
@@ -255,8 +256,8 @@ class API:
 
         return _api_get_time.get_time(self)
 
-    def get_post(self, board: str, aid: Optional[str] = None, index: int = 0,
-                 search_type: data_type.SearchType = data_type.SearchType.NOPE, search_condition: Optional[str] = None,
+    def get_post(self, board: str, aid: Optional[str] = None, index: Optional[int] = None,
+                 search_type: Optional[data_type.SearchType] = None, search_condition: Optional[str] = None,
                  search_list: Optional[List[str]] = None, query: bool = False) -> Dict:
         """
         取得文章。
@@ -310,15 +311,13 @@ class API:
 
     def get_newest_index(self, index_type: data_type.NewIndex, board: Optional[str] = None,
                          search_type: Optional[data_type.SearchType] = None, search_condition: Optional[str] = None,
-                         search_list: Optional[List[str]] = None, ) -> int:
+                         search_list: Optional[List[Tuple[Any | str]]] = None, ) -> int:
         """
         取得最新文章或信箱編號。
 
         Args:
             index_type (:ref:`new-index`): 編號類型。
             board (str): 看板名稱。
-            search_type (:ref:`search-type`) 搜尋類型。
-            search_condition (str): 搜尋條件。
             search_list (List[str]): 搜尋清單。
 
         Returns:
@@ -342,6 +341,22 @@ class API:
             finally:
                 ptt_bot.logout()
 
+
+        取得最新文章編號使用搜尋::
+
+            import PyPtt
+
+            ptt_bot = PyPtt.API()
+
+            search_list = [(PyPtt.SearchType.KEYWORD, 'PyPtt')]
+
+            try:
+                # .. login ..
+                newest_index = ptt_bot.get_newest_index(PyPtt.NewIndex.BOARD, 'Python', search_list=search_list)
+                # .. do something ..
+            finally:
+                ptt_bot.logout()
+
         取得最新信箱編號::
 
             import PyPtt
@@ -911,6 +926,7 @@ class API:
 
         _api_change_pw.change_pw(self, new_password)
 
+    @functools.lru_cache(maxsize=64)
     def get_aid_from_url(self, url: str) -> Tuple[str, str]:
         """
         從網址取得看板名稱與文章編號。
