@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import re
+from typing import Optional
 
 from SingleLog import DefaultLogger
 from SingleLog import LogLevel
@@ -53,39 +54,36 @@ def _get_newest_index(api) -> int:
             break
 
     if newest_index == 0:
-        last_screen = api.connect_core.get_screen_queue()[-1]
-        print(last_screen)
         raise exceptions.UnknownError('UnknownError')
 
     return newest_index
 
 
-def get_newest_index(api, index_type: data_type.NewIndex, board: [str | None] = None,
-                     search_type: data_type.SearchType = None, search_condition: [str | None] = None,
-                     search_list: [list | None] = None) -> int:
+def get_newest_index(api, index_type: data_type.NewIndex, board: Optional[str] = None,
+                     search_type: data_type.SearchType = None, search_condition: Optional[str] = None,
+                     search_list: Optional[list] = None) -> int:
     _api_util.one_thread(api)
 
     if not api._is_login:
         raise exceptions.RequireLogin(i18n.require_login)
 
-    if search_type is None:
-        search_type = data_type.SearchType.NOPE
+    if search_list is None:
+        search_list = []
+    else:
+        check_value.check_type(search_list, list, 'search_list')
 
-    check_value.check_type(index_type, data_type.NewIndex, 'index_type')
-    check_value.check_type(search_type, data_type.SearchType, 'search_type')
+    if (search_type, search_condition) != (None, None):
+        search_list.insert(0, (search_type, search_condition))
 
-    if index_type == data_type.NewIndex.MAIL:
-        if not api.is_registered_user:
-            raise exceptions.UnregisteredUser(lib_util.get_current_func_name())
-
-        if board is not None:
-            raise ValueError('board should not input at NewIndex.MAIL.')
-
-    if search_condition is not None:
+    for search_type, search_condition in search_list:
+        check_value.check_type(search_type, data_type.SearchType, 'search_type')
         check_value.check_type(search_condition, str, 'search_condition')
 
-    if search_list is not None:
-        check_value.check_type(search_list, list, 'search_list')
+    check_value.check_type(index_type, data_type.NewIndex, 'index_type')
+
+    data_key = f'{index_type}_{board}_{search_list}'
+    if data_key in api._newest_index_data:
+        return api._newest_index_data[data_key]
 
     if index_type == data_type.NewIndex.BOARD:
 
@@ -94,9 +92,7 @@ def get_newest_index(api, index_type: data_type.NewIndex, board: [str | None] =
         _api_util.check_board(api, board)
         _api_util.goto_board(api, board)
 
-        cmd_list, normal_newest_index = _api_util.get_search_condition_cmd(api, index_type, board, search_type,
-                                                                           search_condition, search_list)
-
+        cmd_list = []
         cmd_list.append('1')
         cmd_list.append(command.enter)
         cmd_list.append('$')
@@ -110,43 +106,65 @@ def get_newest_index(api, index_type: data_type.NewIndex, board: [str | None] =
                                     exceptions_=exceptions.NoSuchBoard(api.config, board)),
         ]
 
-        if search_type != data_type.SearchType.NOPE:
-            target_list.insert(2, connect_core.TargetUnit(screens.Target.InBoardWithCursor, log_level=LogLevel.DEBUG,
-                                                          break_detect=True))
-
         index = api.connect_core.send(cmd, target_list)
         if index < 0:
-            # OriScreen = api.connect_core.getScreenQueue()[-1]
-            # print(OriScreen)
             raise exceptions.NoSuchBoard(api.config, board)
 
         if index == 0:
             return 0
 
-        newest_index = _get_newest_index(api)
+        normal_newest_index = _get_newest_index(api)
 
-        if normal_newest_index == newest_index:
-            raise exceptions.NoSearchResult()
+        if search_list is not None and len(search_list) > 0:
+            target_list.insert(2,
+                               connect_core.TargetUnit(
+                                   screens.Target.InBoardWithCursor,
+                                   log_level=LogLevel.DEBUG,
+                                   break_detect=True))
+
+            cmd_list = _api_util.get_search_condition_cmd(index_type, search_list)
+
+            cmd_list.append('1')
+            cmd_list.append(command.enter)
+            cmd_list.append('$')
+            cmd = ''.join(cmd_list)
+
+            index = api.connect_core.send(cmd, target_list)
+            if index < 0:
+                raise exceptions.NoSuchBoard(api.config, board)
+
+            if index == 0:
+                return 0
+
+            newest_index = _get_newest_index(api)
+
+            if normal_newest_index == newest_index:
+                raise exceptions.NoSearchResult()
+        else:
+            newest_index = normal_newest_index
 
     elif index_type == data_type.NewIndex.MAIL:
 
+        if not api.is_registered_user:
+            raise exceptions.UnregisteredUser(lib_util.get_current_func_name())
+
+        if board is not None:
+            raise ValueError('board should not input at NewIndex.MAIL.')
+
         cmd_list = []
         cmd_list.append(command.go_main_menu)
         cmd_list.append(command.ctrl_z)
         cmd_list.append('m')
 
-        _cmd_list, normal_newest_index = _api_util.get_search_condition_cmd(api, index_type, board, search_type,
-                                                                            search_condition, search_list)
-        # print('normal_newest_index', normal_newest_index)
-
-        cmd_list.extend(_cmd_list)
-        cmd_list.append(command.ctrl_f * 50)
+        cmd_list.append('1')
+        cmd_list.append(command.enter)
+        cmd_list.append('$')
 
         cmd = ''.join(cmd_list)
 
         target_list = [
             connect_core.TargetUnit(screens.Target.InMailBox, break_detect=True),
-            connect_core.TargetUnit(screens.Target.CursorToGoodbye, log_level=LogLevel.DEBUG, break_detect=True),
+            connect_core.TargetUnit(screens.Target.CursorToGoodbye, response=cmd),
         ]
 
         def get_index(api):
@@ -167,22 +185,48 @@ def get_newest_index(api, index_type: data_type.NewIndex, board: [str | None] =
             return newest_index
 
         newest_index = 0
-        for i in range(3):
-            index = api.connect_core.send(
-                cmd,
-                target_list)
-            # print('index', index)
-            # last_screen = api.connect_core.get_screen_queue()[-1]
-            # print(last_screen)
 
-            if index == 0:
-                newest_index = get_index(api)
-                if normal_newest_index == newest_index:
-                    if i == 2:
+        index = api.connect_core.send(
+            cmd,
+            target_list)
+
+        if index == 0:
+            normal_newest_index = get_index(api)
+
+            if search_list is not None and len(search_list) > 0:
+                target_list.insert(2,
+                                   connect_core.TargetUnit(
+                                       screens.Target.InMailBoxWithCursor,
+                                       log_level=LogLevel.DEBUG,
+                                       break_detect=True)
+                                   )
+
+                cmd_list = []
+                cmd_list.append(command.go_main_menu)
+                cmd_list.append(command.ctrl_z)
+                cmd_list.append('m')
+
+                cmd_list.extend(
+                    _api_util.get_search_condition_cmd(index_type, search_list)
+                )
+
+                cmd_list.append('1')
+                cmd_list.append(command.enter)
+                cmd_list.append('$')
+
+                cmd = ''.join(cmd_list)
+
+                index = api.connect_core.send(
+                    cmd,
+                    target_list)
+
+                if index in [0, 2]:
+                    newest_index = get_index(api)
+                    if normal_newest_index == newest_index:
                         raise exceptions.NoSearchResult()
-                    else:
-                        continue
-                break
-            newest_index = 0
 
+            else:
+                newest_index = normal_newest_index
+
+    api._newest_index_data[data_key] = newest_index
     return newest_index
