@@ -1,8 +1,9 @@
 from __future__ import annotations
 
+import functools
 import re
 import threading
-from typing import Dict
+from typing import Dict, Optional
 
 from SingleLog import DefaultLogger
 from SingleLog import LogLevel
@@ -93,8 +94,10 @@ def get_content(api, post_mode: bool = True):
         else:
             # 這裡是根據觀察畫面行數的變化歸納出的神奇公式...
             # 輸出的結果是要判斷出畫面的最後 x 行是新的文章內容
-            # 這裡的一切都太可怕，每除完一次錯誤，我的腦袋會選擇 flush 掉一次
-            # 所以這裡的變數名稱都是很亂的，請見諒
+            #
+            # 這裡是 PyPtt 最黑暗最墮落的地方，所有你所知的程式碼守則，在這裡都不適用
+            # 每除完一次錯誤，我會陷入嚴重的創傷後壓力症候群，而我的腦袋會自動選擇遺忘這裡所有的一切
+            # 以確保下一個週一，我可以正常上班
             # but it works!
 
             # print(LastScreen)
@@ -179,7 +182,15 @@ def get_content(api, post_mode: bool = True):
     return origin_post, has_control_code
 
 
-def get_mailbox_capacity(api):
+mail_capacity: Optional[tuple[int, int]] = None
+
+
+def get_mailbox_capacity(api) -> tuple[int, int]:
+
+    global mail_capacity
+    if mail_capacity is not None:
+        return mail_capacity
+
     last_screen = api.connect_core.get_screen_queue()[-1]
     capacity_line = last_screen.split('\n')[2]
 
@@ -188,13 +199,13 @@ def get_mailbox_capacity(api):
 
     pattern_result = re.compile('(\d+)/(\d+)').search(capacity_line)
     if pattern_result is not None:
-        # print(pattern_result.group(0))
         current_capacity = int(pattern_result.group(0).split('/')[0])
         max_capacity = int(pattern_result.group(0).split('/')[1])
 
         logger.debug('current_capacity', current_capacity)
         logger.debug('max_capacity', max_capacity)
 
+        mail_capacity = (current_capacity, max_capacity)
         return current_capacity, max_capacity
     return 0, 0
 
@@ -235,10 +246,8 @@ def parse_query_post(api, ori_screen):
     elif ' R:' in post_title:
         post_title = post_title[post_title.find('R:'):].strip()
     elif ' 轉 ' in post_title:
-        # print(f'[{PostTitle}]=========>')
         post_title = post_title[post_title.find('轉') + 1:].strip()
         post_title = f'Fw: {post_title}'
-        # print(f'=========>[{PostTitle}]')
     elif ' 鎖 ' in post_title:
         post_title = post_title[post_title.find('鎖') + 1:].strip()
 
@@ -289,6 +298,7 @@ def parse_query_post(api, ori_screen):
 
     pattern = re.compile('[\d]+')
     pattern_result = pattern.search(cursor_line)
+    post_index = 0
     if pattern_result is not None:
         post_index = int(pattern_result.group(0))
 
@@ -333,19 +343,12 @@ def parse_query_post(api, ori_screen):
     return lock_post, post_author, post_title, post_aid, post_web, post_money, list_date, push_number, post_index
 
 
-def get_search_condition_cmd(api, index_type: data_type.NewIndex, board: [str | None] = None,
-                             search_type: data_type.SearchType = data_type.SearchType.NOPE,
-                             search_condition: [str | None] = None, search_list: [list | None] = None):
-    # log.py = DefaultLogger('get_search_condition_cmd')
+def get_search_condition_cmd(index_type: data_type.NewIndex, search_list: Optional[list] = None):
     cmd_list = []
+    if not search_list:
+        return cmd_list
 
-    normal_newest_index = -1
-    if search_condition is not None:
-
-        if index_type == data_type.NewIndex.BOARD:
-            normal_newest_index = api.get_newest_index(index_type, board=board)
-        else:
-            normal_newest_index = api.get_newest_index(index_type)
+    for search_type, search_condition in search_list:
 
         if search_type == data_type.SearchType.KEYWORD:
             cmd_list.append('/')
@@ -353,48 +356,20 @@ def get_search_condition_cmd(api, index_type: data_type.NewIndex, board: [str |
             cmd_list.append('a')
         elif search_type == data_type.SearchType.MARK:
             cmd_list.append('G')
-
-        if index_type == data_type.NewIndex.BOARD:
+        elif index_type == data_type.NewIndex.BOARD:
             if search_type == data_type.SearchType.COMMENT:
                 cmd_list.append('Z')
             elif search_type == data_type.SearchType.MONEY:
                 cmd_list.append('A')
+            else:
+                continue
+        else:
+            continue
 
         cmd_list.append(search_condition)
         cmd_list.append(command.enter)
 
-    if search_list is not None:
-
-        if normal_newest_index == -1:
-            if index_type == data_type.NewIndex.BOARD:
-                normal_newest_index = api.get_newest_index(index_type, board=board)
-            else:
-                normal_newest_index = api.get_newest_index(index_type)
-
-        for search_type_, search_condition_ in search_list:
-
-            # print('==>', search_type_, search_condition_)
-
-            if search_type_ == data_type.SearchType.KEYWORD:
-                cmd_list.append('/')
-            elif search_type_ == data_type.SearchType.AUTHOR:
-                cmd_list.append('a')
-            elif search_type_ == data_type.SearchType.MARK:
-                cmd_list.append('G')
-            elif index_type == data_type.NewIndex.BOARD:
-                if search_type_ == data_type.SearchType.COMMENT:
-                    cmd_list.append('Z')
-                elif search_type_ == data_type.SearchType.MONEY:
-                    cmd_list.append('A')
-                else:
-                    continue
-            else:
-                continue
-
-            cmd_list.append(search_condition_)
-            cmd_list.append(command.enter)
-
-    return cmd_list, normal_newest_index
+    return cmd_list
 
 
 def goto_board(api, board: str, refresh: bool = False, end: bool = False) -> None:
@@ -443,6 +418,7 @@ def one_thread(api):
         raise exceptions.MultiThreadOperated()
 
 
+@functools.lru_cache(maxsize=64)
 def check_board(api, board: str, check_moderator: bool = False) -> Dict:
     if board.lower() not in api._exist_board_list:
         board_info = _api_get_board_info.get_board_info(api, board, get_post_kind=False, call_by_others=False)
